pub struct AsioPort { /* private fields */ }Expand description
Routable ASIO port owned by a driver.
Implementations
Sourceimpl AsioPort
impl AsioPort
Sourcepub fn new(
id: Symbol,
driver: Symbol,
name: String,
direction: HostDirection,
index: usize,
) -> Self
pub fn new( id: Symbol, driver: Symbol, name: String, direction: HostDirection, index: usize, ) -> Self
Builds a PCM port with the given id, owning driver id, name, direction, and per-direction channel index.
Sourcepub fn media(&self) -> StreamMedia
pub fn media(&self) -> StreamMedia
Returns the port media, always StreamMedia::Pcm for ASIO.
Sourcepub fn direction(&self) -> HostDirection
pub fn direction(&self) -> HostDirection
Returns whether the port is an input or output.